# Digit-RAN and dice-RAN in Chinese control and dyslexic children
# March 26

# v5 vs. v4: Use a slightly different "final" model m09 (leave in one non-significant interaction)
# v7: don' estimate intercept and slopes for main models; use only at the end for illustrative purposes.
# v8: lower-bound pvalues
# v9:  3-factor intercation for GD (Hawelka & Gagl)
# Jinger Pan & Reinhold Kliegl
# marking log(RAN) as lran rather than ran (Jinger Pan # 11 Dec 2012)

library(ggplot2)
library(grid)
library(reshape2)
library(plyr)
library(MASS)
library(lme4)
library("LMERConvenienceFunctions" ) 
library(gtools)
rm(list=ls())

source("remef.v0.6.9.R")

RKstats <- function(x) c(M=mean(x), SD=sd(x), N=length(x), SE=sd(x)/sqrt(length(x)) )

vplayout <- function(x, y) {
viewport(layout.pos.row = x, layout.pos.col = y) 
}

load("psycho_1256_fixdur_R1.rda")
data <- dat
data$Subj <- factor(data$subj)
data$Group <- factor(data$group, labels=c("control", "dyslexic"))
data$Condition <- factor(data$condition, labels=c("digit", "dice"))

# Check distributions of continuous variables
boxcox(ran ~ subj*condition, data=data)
boxcox(gaze ~ subj*condition, data=data)
boxcox(evs ~ subj*condition, data=data)
# Justifies log-transform of ran, not of gaze and evs
data$lran <- log(data$ran)
lambdaList<-boxcox(ran ~ subj*condition, data=data)
lambda <- lambdaList$x[which.max(lambdaList$y)] 
data$pran <- data$ran^(lambda)

# Effect coding of factors
data$group <- ifelse(data$group==1, 0.5, -0.5)         # control=0.5, dyslexic= -0.5
data$condition <- ifelse(data$condition==1, 0.5, -0.5) # digit=0.5, dice= -0.5

# Center covariates
data$gaze.c <- scale(data$gaze,scale=FALSE,center=TRUE)
data$evs.c <- scale(data$evs,scale=FALSE,center=TRUE)

#--------------------------------------------
# Group correlations
data_w <- cbind(data[data$Condition=="digit", ], data[data$Condition=="dice", ])[ , c(9:10, 4, 19, 6, 21, 5, 20)]
names(data_w) <- c("Subj", "Group", "g_ran", "c_ran", "g_evs", "c_evs", "g_gaze", "c_gaze")
options(digits=2)
cor(data_w[     , 3:8]) # all
cor(data_w[ 1:26, 3:8]) # control
cor(data_w[27:56, 3:8]) # dyslexic


#---------------------------------------------------------------
#---------------------------------------------------------------
# Basic group x condition interaction for psychometric RAN (pmRAN)
M_RAN=ddply(data, c("Group","Condition"), with, each(RKstats)(lran))
qplot(data=M_RAN, x=Group, y=M, group=Condition, shape=Condition, geom=c("line", "point"), ylab="log(RAN)", ylim=c(2, 4)) + 
      geom_errorbar(aes(max=M+2*SE, min=M-2*SE, width=0.1)) + theme_bw()

summary(r1  <- lmer(lran ~ group*condition + (1 | subj), data=data))
#------------------------------------------------
# Gaze -- replicates pattern for pmRAN
M_gaze=ddply(data, c("Group","Condition"),  with, each(RKstats)(gaze))
qplot(data=M_gaze, x=Group, y=M, group=Condition, shape=Condition, geom=c("line", "point"), ylab="Gaze duration (ms)") + 
      geom_errorbar(aes(max=M+2*SE, min=M-2*SE, width=0.1)) + theme_bw()

summary(g1 <- lmer(gaze ~ group*condition + (1 | subj), data=data))

# So if we include gaze as covariate for pmRAN
summary(r1.ML <- lmer(lran ~ group*condition + (1 | subj), data=data, REML=FALSE))
summary(r2.ML <- lmer(lran ~ group*condition+gaze.c + (1 | subj), data=data, REML=FALSE))
summary(r2a.ML <- lmer(lran ~ (group+condition+gaze.c)^2 + (1 | subj), data=data, REML=FALSE ))
summary(r2b.ML <- lmer(lran ~ (group+condition+gaze.c)^3 + (1 | subj), data=data, REML=FALSE ))
anova(r1.ML, r2.ML, r2a.ML, r2b.ML) 

# r2.ML looks like best model

# Three main effects (group, condition, gaze.c), plus significant group * condition interaction
summary(r2 <- lmer(lran ~ group*condition+gaze.c + (1 | subj), data=data))

#------------------------------------------------
# EVS -- replicates pattern for pmRAN
M_EVS=ddply(data, c("Group","Condition"), with, each(RKstats)(evs))
qplot(data=M_EVS, x=Group, y=M, group=Condition, shape=Condition, geom=c("line", "point"), ylab="Eye-voice span (char)") + 
      geom_errorbar(aes(max=M+1*SE, min=M-1*SE, width=0.1)) + theme_bw()

summary(e1  <- lmer(evs ~ group*condition + (1 | subj), data=data))

# So if we include evs as covariate for pmRAN,
data$evs.c <- scale(data$evs,scale=FALSE,center=TRUE)
summary(r3.ML <- lmer(lran ~ group*condition+evs.c + (1 | subj), data=data, REML=FALSE))
summary(r3a.ML <- lmer(lran ~ (group+condition+evs.c)^2 + (1 | subj), data=data, REML=FALSE))
summary(r3b.ML <- lmer(lran ~ (group+condition+evs.c)^3 + (1 | subj), data=data, REML=FALSE))
anova(r1.ML, r3.ML, r3a.ML, r3b.ML)  # evs.c is significant covariate


# Three main effects (group, condition, evs.c), plus significant condition*group interaction
summary(r3 <- lmer(lran ~ condition*group+evs.c + (1 | subj), data=data))

#------------------------------------------------
# GAZE + EVS
summary(m00.ML <- lmer(lran ~ condition+group+evs.c+gaze.c + (1  | subj), data=data, REML=FALSE))

# Minimum model given previous results
summary(m05.ML <- lmer(lran ~ condition*group+evs.c+gaze.c + (1  | subj), data=data, REML=FALSE))

# Full factorial 
summary(m10.ML <- lmer(lran ~ condition*group*evs.c*gaze.c + (1  | subj), data=data, REML=FALSE))

# Remove 3 non-significant higher-order interactions involving evs.c:gaze.c
summary(m09.ML <- lmer(lran ~ condition*group*evs.c*gaze.c - condition:group:evs.c:gaze.c 
	                     - group:evs.c:gaze.c - condition:gaze.c:evs.c
	                     + (1  | subj), data=data, REML=FALSE))
anova(m00.ML, m05.ML, m09.ML, m10.ML)

# Best model; reported in Table 3
summary(m09 <- lmer(lran ~ condition*group*evs.c*gaze.c - condition:group:evs.c:gaze.c 
	                     - group:evs.c:gaze.c - condition:gaze.c:evs.c
	                     + (1  | subj), data=data))

# ... get confidence intervals for parameters of fitted model, cannot use anymore in the lme1.1-2?
m09mcmc <- mcmcsamp(m09, 10000)
HPDinterval(m09mcmc) # reported in Table 3

#----------------------------------
# Did we need to log-transform ran?
summary(m09.ranraw <- lmer(exp(lran) ~ condition*group*evs.c*gaze.c - condition:group:evs.c:gaze.c 
	                     - group:evs.c:gaze.c - condition:gaze.c:evs.c
	                     + (1 | subj), data=data))
# ... Not for three critical interactions

#--------------------------------------------------------
# How relevant are polynomial trends in evs.c and gaze.c?

### TO BE DONE ###
      
#-------------------------------------------------------------------
# PLOTS -- unadjusted and partial plots (model m09) of interactions
theme_set(theme_bw())
#-------------------------------------------------------------------
# ... Condition x  Group x EVS (t=-2.6)
# ... ... unadjusted
p1 <- qplot(data=data, y=lran, x=evs,  group=Condition:Group, shape=Condition:Group, linetype=Condition:Group, geom=c("point", "smooth"), method=lm,
      xlab = "Eye-voice span", ylab="log(RAN)", ylim=c(2, 4))  + scale_linetype_manual(values=c(1,2,3,4)) + 
	  scale_shape_manual(values=c(0,15,1,16)) + geom_smooth(size=1,method=lm,color="black") + geom_point(size=2.5) +
      theme(legend.position = "none", panel.background=element_rect(fill = "white"))


# Always put opts() last!
# qplot(data=data, y=ran, x=evs,  group=Condition:Group, color=Condition:Group, geom=c("point", "smooth"), method=lm,
#	    xlab = "Eye-voice span", ylab="log(RAN)", ylim=c(2, 4)) + theme_bw() + 
#	    opts(legend.position = "none")

# ... ... -- evs for dice better predictor for dyslexic, 
# ... ... -- evs for digits better predictor for control

# ... ... partial effects
data$CndGrpEVS.m09 <- remef(m09, keep=TRUE, grouping=TRUE, fix = c(1, "condition:group:evs.c"), ran = NULL, plot=FALSE) 
p2 <- qplot(data=data, y=CndGrpEVS.m09, x=evs, group=Condition:Group, shape=Condition:Group, linetype=Condition:Group, geom=c("point", "smooth"), method=lm,
      xlab = "Eye-voice span", ylab="Adjusted log(RAN)", ylim=c(2, 4)) + scale_linetype_manual(values=c(1,2,3,4)) +
      scale_shape_manual(values=c(0,15,1,16)) + geom_smooth(size=1,method=lm,color="black") + geom_point(size=2.5) +
      theme(legend.position = c(.30, .20), legend.text = element_text(size=12), panel.background=element_rect(fill = "white")) 

# Always put opts() last!
#qplot(data=data, y=CndGrpEVS.m09, x=evs, group=Condition:Group, color=Condition:Group, geom=c("point", "smooth"), method=lm,
#	      xlab = "Eye-voice span", ylab="Adjusted log(RAN)", ylim=c(2, 4)) + theme_bw() +
#	      opts(legend.position = c(.82, .76), legend.text = theme_text(size=12))

# ... ... -- evs only predictor for control in digit-RAN!

grid.newpage() # RAN.Fig1.pdf, also Manuscript.Fig1.pdf
pushViewport(viewport(layout = grid.layout(1,2))) 
print(p1, vp=vplayout(1,1))
print(p2, vp=vplayout(1,2))



#------------------------------------------------------
# ... EVSgroup x GAZE
# ... form two EVS groups
idEVS <- ddply(data, "Subj", with, each(M=mean)(evs))
idEVS$EVSgroup.2 <- quantcut(idEVS$M, seq(0, 1, by=1/2), label=c("small", "large"))
data1 <- merge(data, idEVS, by="Subj")

idGD <- ddply(data, "Subj", with, each(M=mean)(gaze))
idGD$GDgroup.2 <- quantcut(idGD$M, seq(0, 1, by=1/2), label=c("short", "long"))
data2 <- merge(data, idGD, by="Subj")


# ... ... partial effects
# ... EVSgroup x GAZE 
# ... ... for two EVS groups
data1$EVS_GAZE.m09  <- remef(m09, keep=TRUE, grouping=TRUE, fix = c(1, "evs.c:gaze.c"), ran = NULL, plot=FALSE)
p8 <- qplot(data=data1, y=EVS_GAZE.m09, x=gaze, group=EVSgroup.2, shape=EVSgroup.2, linetype=EVSgroup.2, geom=c("point", "smooth"), method=lm, 
      xlab = "Gaze duration", ylab="Adjusted log(RAN)", ylim=c(2, 4)) + scale_linetype_manual(name="EVS group",values=c(1,4)) +
	  scale_shape_manual(name="EVS group",values=c(1,15)) + geom_smooth(size=1,method=lm,color="black") + geom_point(size=2.5) +
      theme(legend.position = c(.75, .25),legend.text = element_text(size=12),panel.background=element_rect(fill = "white")) 

#--------------------------------------------------------------------------------------------
# ... CHECK of asymmetry of EVS and GAZE: Condition x  Group x GAZE (t=0.3) : not significant!!

# ... ... partial effects
data$CndGrpGAZE.m09 <- remef(m09, keep=TRUE, grouping=TRUE, fix = c(1, "condition:group:gaze.c"), ran = NULL, plot=FALSE) 
p10 <- qplot(data=data, y=CndGrpGAZE.m09, x=gaze, group=Condition:Group,shape=Condition:Group, linetype=Condition:Group,
             geom=c("point", "smooth"), method=lm, xlab = "Gaze duration", ylab="Adjusted log(RAN)", ylim=c(2, 4))  + 
			 scale_linetype_manual(values=c(1,2,3,6)) + scale_shape_manual(values=c(0,15,1,16)) + geom_smooth(size=1,method=lm) +
			 geom_smooth(size=1,method=lm,color="black") + geom_point(size=2.5) +
      theme(legend.position = c(.75, .25), legend.text = element_text(size=12),panel.background=element_rect(fill = "white")) 
# ... ... -- dice control slope looks different, but this difference is not strong enough?

 
grid.newpage()  # Manuscript New Figure 2
pushViewport(viewport(layout = grid.layout(1,2))) 
print(p10, vp=vplayout(1,1))
print(p8, vp=vplayout(1,2))
